@@ -19,7 +19,7 @@ Every task is made easy with tons of ``help`` & ``debug`` commands!
 
 __title__ = 'geocoder'
 __author__ = 'Denis Carriere'
-__version__ = '0.8.1'
+__version__ = '0.8.3'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2014 Denis Carriere'
 
@@ -27,4 +27,6 @@ __copyright__ = 'Copyright 2014 Denis Carriere'
 from .api import yahoo, bing, geonames, google, mapquest, nokia, osm, tomtom, geolytica, arcgis
 
 # EXTRAS
-from .api import ip, canadapost, timezone, elevation, geocode
+from .api import ip, canadapost, timezone, elevation, get
+
+from cli import cli
