@@ -10,15 +10,79 @@ from .yahoo import Yahoo
 from .tomtom import Tomtom
 from .google import Google
 from .arcgis import Arcgis
-from .reverse import Reverse
 from .geonames import Geonames
 from .mapquest import Mapquest
 from .timezone import Timezone
 from .elevation import Elevation
 from .geolytica import Geolytica
 from .canadapost import Canadapost
+from .bing_reverse import BingReverse
+from .google_reverse import GoogleReverse
 
 
+def get(location, provider='google', reverse=False):
+    """
+    # Get
+
+    The Get function is a simple way to input the Geocoding provider as a variable.
+
+    ## Python Example
+
+        >>> import geocoder # pip install geocoder
+        >>> g = geocoder.get('<address>', provider='bing')
+        >>> g.lat, g.lng
+        45.413140 -75.656703
+        ...
+
+    ## Geocoder Attributes
+
+        * address
+        * country
+        * county
+        * lat
+        * lng
+        * locality
+        * location
+        * neighborhood
+        * postal
+        * provider
+        * quality
+        * route
+        * state
+        * status
+        * street_number
+
+    ## Parameters
+
+        * :param ``location``: Your search location you want geocoded.
+        * :param ``provider``: The geocoding engine you want to use.
+        * :param ``reverse``: Use True to apply a reverse geocoding to a LatLng input.
+
+    ## References
+
+        * [GitHub Repo](https://github.com/DenisCarriere/geocoder)
+        * [GitHub Wiki](https://github.com/DenisCarriere/geocoder/wiki)
+
+    """
+    provider = provider.lower().strip()
+    options = dict()
+    options['ip'] = Ip
+    options['osm'] = Osm
+    options['bing'] = Bing
+    options['nokia'] = Nokia
+    options['yahoo'] = Yahoo
+    options['google'] = Google
+    options['tomtom'] = Tomtom
+    options['arcgis'] = Arcgis
+    options['geonames'] = Geonames
+    options['mapquest'] = Mapquest
+    options['timezone'] = Timezone
+    options['elevation'] = Elevation
+    options['geolytica'] = Geolytica
+    options['canadapost'] = Canadapost
+
+    return options[provider](location)
+
 def yahoo(location):
     """
     # Yahoo
@@ -152,7 +216,7 @@ def arcgis(location):
     """
     return Arcgis(location)
 
-def bing(location, key=bing_key):
+def bing(location, reverse=False, key=bing_key):
     """
     # Bing
 
@@ -198,7 +262,10 @@ def bing(location, key=bing_key):
         * [Bing Maps REST Services](http://msdn.microsoft.com/en-us/library/ff701714.aspx)
 
     """
-    return Bing(location, key=key)
+    if reverse:
+        return BingReverse(location, key=key)
+    else:
+        return Bing(location, key=key)
 
 def nokia(location, app_id=app_id, app_code=app_code):
     """
@@ -391,7 +458,7 @@ def osm(location):
     """
     return Osm(location)
 
-def google(location, short_name=True):
+def google(location, reverse=False, short_name=True):
     """
     # Google
 
@@ -441,7 +508,10 @@ def google(location, short_name=True):
         * [Google Geocoding API](https://developers.google.com/maps/documentation/geocoding/)
 
     """
-    return Google(location, short_name=short_name)
+    if reverse:
+        return GoogleReverse(location, short_name=short_name)
+    else:
+        return Google(location, short_name=short_name)
 
 def ip(location):
     """
@@ -583,59 +653,8 @@ def elevation(location):
     """
     return Elevation(location)
 
-def reverse(location, short_name=True):
-    """
-    # Reverse
 
-    The term geocoding generally refers to translating a human-readable address into
-    a location on a map. The process of doing the opposite, translating a location
-    on the map into a human-readable address, is known as reverse geocoding.
-    Using Geocoder you can retrieve Reverse's geocoded data from Google Geocoding API.
-
-    ## Python Example
-
-        >>> import geocoder
-        >>> g = geocoder.reverse(['lat','lng'])
-        >>> g.address
-        '453 Booth Street, Ottawa'
-        ...
-
-    ## Geocoder Attributes
-
-        * accuracy
-        * address
-        * bbox
-        * country
-        * county
-        * lat
-        * lng
-        * locality
-        * location
-        * neighborhood
-        * postal
-        * provider
-        * quality
-        * route
-        * state
-        * status
-        * street_number
-        * sublocality
-
-    ## Parameters
-
-        * :param ``location``: Your search location you want geocoded.
-        * :param ``short_name``: (optional) if ``False`` will retrieve the results with Long names.
-
-    ## References
-
-        * [GitHub Repo](https://github.com/DenisCarriere/geocoder)
-        * [GitHub Wiki](https://github.com/DenisCarriere/geocoder/wiki)
-        * [Google Geocoding API](https://developers.google.com/maps/documentation/geocoding/)
-
-    """
-    return Reverse(location)
-
-def canadapost(location, country='CA', key=''):
+def canadapost(location, key=canadapost_key, reverse=False):
     """
     # CanadaPost
 
@@ -680,7 +699,7 @@ def canadapost(location, country='CA', key=''):
         * [Addres Complete API](https://www.canadapost.ca/pca/)
 
     """
-    return Canadapost(location, country=country, key=key)
+    return Canadapost(location, key=key, reverse=reverse)
 
 def geonames(location, username='addxy'):
     """
@@ -725,3 +744,5 @@ def geonames(location, username='addxy'):
 
     """
     return Geonames(location, username=username)
+
+
