@@ -12,9 +12,10 @@ class Base(object):
                        '[GitHub Wiki](https://github.com/DenisCarriere/geocoder/wiki)']
     _exclude = ['parse', 'json', 'url', 'attributes', 'help', 'debug', 'short_name',
                 'api', 'description', 'content', 'params', 'status_code', 'headers',
-                'status_description', 'api_key', 'ok', 'key', 'id', 'x', 'y']
+                'status_description', 'api_key', 'ok', 'key', 'id', 'x', 'y', 'latlng',
+                'bbox', 'geometry', 'wkt']
     _example = []
-    _timeout = None
+    _timeout = 5.0
     attributes = []
     headers = {}
     error = ''
@@ -93,6 +94,7 @@ class Base(object):
                     self.json[key] = value
 
     def _connect(self):
+        self.content = None
         self.status_code = 404
         try:
             r = requests.get(self.url, params=self.params, headers=self.headers, timeout=self._timeout)
@@ -238,16 +240,16 @@ class Base(object):
         self.north = north
         self.east = east
 
+        # Bounding Box Corners
+        self.northeast = [north, east]
+        self.northwest = [north, west]
+        self.southwest = [south, west]
+        self.southeast = [south, east]
+
         if bool(south and east and north and west):
             bbox = dict()
-            bbox['type'] = 'Polygon'
-            bbox['coordinates'] = [
-                [west, south],
-                [east, south],
-                [east, north],
-                [west, north],
-                [west, south]
-            ]
+            bbox['northeast'] = [north, east]
+            bbox['southwest'] = [south, west]
             return bbox
         return str('')
 
@@ -270,9 +272,12 @@ class Base(object):
     @property
     def wkt(self):
         if self.ok:
-            return 'POINT({x} {y})'.format(x=self.lng, y=self.lat)
-        return str('')
+            return 'POINT({x} {y})'.format(x=self.x, y=self.y)
+        return '' 
 
+    @property
+    def latlng(self):
+        return [self.lat, self.lng]
 
     @property
     def y(self):
