@@ -27,6 +27,7 @@ class Google(Base):
         self._connect()
         self._parse(self.content)
         self._json()
+        self.bbox
 
     @property
     def lat(self):
@@ -67,6 +68,13 @@ class Google(Base):
         else:
             return self._get_json_str('postal_code-long_name')
 
+    @property
+    def subpremise(self):
+        if self.short_name:
+            return self._get_json_str('subpremise')
+        else:
+            return self._get_json_str('subpremise-long_name')
+
     @property
     def street_number(self):
         if self.short_name:
