@@ -65,6 +65,11 @@ class Location(object):
             if bool(lat and lng):
                 return lat, lng
 
+    @property
+    def latlng(self):
+        return '{0},{1}'.format(self.lat, self.lng)
+
+
 if __name__ == '__main__':
     pass
 
