@@ -21,7 +21,6 @@ def test_entry_points():
     geocoder.google
     geocoder.tomtom
     geocoder.arcgis
-    geocoder.reverse
     geocoder.geonames
     geocoder.mapquest
     geocoder.timezone
@@ -58,14 +57,31 @@ def test_canadapost():
     g = geocoder.canadapost(address)
     assert g.ok
 
+"""
+Not Working at the moment
+
+def test_canadapost_reverse():
+    g = geocoder.canadapost(ottawa, reverse=True)
+    assert g.ok
+
+"""
+
 def test_google():
     g = geocoder.google(location)
     assert g.ok
 
+def test_google_reverse():
+    g = geocoder.google(ottawa, reverse=True)
+    assert g.ok
+
 def test_bing():
     g = geocoder.bing(location)
     assert g.ok
 
+def test_bing_reverse():
+    g = geocoder.bing(ottawa, reverse=True)
+    assert g.ok
+
 def test_nokia():
     g = geocoder.nokia(location)
     assert g.ok
@@ -86,10 +102,6 @@ def test_geonames():
     g = geocoder.geonames(location)
     assert g.ok
 
-def test_reverse():
-    g = geocoder.reverse(ottawa)
-    assert g.ok
-
 def test_ip():
     g = geocoder.ip(ip)
     assert g.ok
\ No newline at end of file
